@@ -18,6 +18,7 @@ from django.urls import path, include, re_path
 from django.views.static import serve
 from django.conf import settings
 from django.views.i18n import JavaScriptCatalog
+import notifications.urls
 
 urlpatterns = [
     path('grappelli/', include('grappelli.urls')),
@@ -25,6 +26,8 @@ urlpatterns = [
     re_path(r'^chaining/', include('smart_selects.urls')),
     re_path(r'^simditor/', include('simditor.urls')),
     path('autopost/', include('autopost.urls')),
+    path('inbox/notifications/', include(notifications.urls, namespace='notifications')),
+    # path('comment/', include('qt_comment.urls'), name='comment'),
     # path('uc/', include('usercenter.urls'), name='uc'),
     re_path(r'^jsi18n/$', JavaScriptCatalog.as_view(), name='javascript-catalog'),
 ]
